@@ -1,8 +1,12 @@
 import pandas as pd
 import pickle
-from dateutil import parser
 import urllib2
+import urllib
+import datetime
+from dateutil import parser
+
 from numpy import genfromtxt
+
 #TODO:Needs more debugging and tests,only a limited amount of testing done.
 
 
@@ -141,7 +145,6 @@ def push(data, code, name, authtoken='', desc='', override = False):
     url = "http://www.quandl.com/api/v1/datasets.json?auth_token=" + token 
     
     jsonreturn = _htmlpush(url,params)
-    print jsonreturn["errors"]
     if jsonreturn["errors"] and jsonreturn["errors"]["code"][0] == "has already been taken":
         error = "You are trying to overwrite a dataset which already exists on Quandl. If this is what you wish to do please recall the function with overide = True"
         raise Exception(error)
@@ -178,6 +181,7 @@ def _download(url):
     
 #Helper function to make html push
 def _htmlpush(url,raw_params):
+    import json
     page = url
     params = urllib.urlencode(raw_params)
     request = urllib2.Request(page, params)
@@ -186,6 +190,7 @@ def _htmlpush(url,raw_params):
 
 
 def _pushcodetest(code):
+    import re
     regex = re.compile('[^0-9A-Z_]')
     if not regex.search(code):
         return code
